@@ -102,23 +102,22 @@ class FileTreePanel(ctrlpanel.ControlPanel):
         self.__customTree   = wx.Button(self)
         self.__treeChoice   = wx.Choice(self)
         self.__save         = wx.Button(self)
-        self.__dirName      = wx.StaticText(self, style=wx.ST_ELLIPSIZE_MIDDLE)
         self.__mainSplitter = wx.SplitterWindow(
             self, style=wx.SP_LIVE_UPDATE | wx.SP_BORDER)
         self.__leftPanel    = wx.Panel(self.__mainSplitter)
-        self.__leftSizer    = wx.BoxSizer(wx.VERTICAL)
+        self.__rightPanel   = wx.Panel(self.__mainSplitter)
+        self.__notesLabel   = wx.StaticText(self.__leftPanel)
+        self.__notesChoice  = wx.Choice(self.__leftPanel)
+        self.__dirName      = wx.StaticText(
+            self.__rightPanel, style=wx.ST_ELLIPSIZE_MIDDLE)
 
-        self.__varPanel     = VariablePanel(self.__leftPanel,    self)
-        self.__fileTypes    = FileTypePanel(self.__leftPanel,    self)
-        self.__fileList     = FileListPanel(self.__mainSplitter, self)
-
-        self.__leftSizer.Add(self.__fileTypes, flag=wx.EXPAND, proportion=1)
-        self.__leftSizer.Add(self.__varPanel,  flag=wx.EXPAND)
-        self.__leftPanel.SetSizer(self.__leftSizer)
+        self.__varPanel     = VariablePanel(self.__leftPanel,  self)
+        self.__fileTypes    = FileTypePanel(self.__leftPanel,  self)
+        self.__fileList     = FileListPanel(self.__rightPanel, self)
 
         self.__mainSplitter.SetMinimumPaneSize(50)
-        self.__mainSplitter.SplitVertically(  self.__leftPanel,
-                                              self.__fileList)
+        self.__mainSplitter.SplitVertically(
+            self.__leftPanel, self.__rightPanel)
         self.__mainSplitter.SetSashGravity(0.3)
 
         # Build a list of all built-in filetrees,
@@ -138,27 +137,52 @@ class FileTreePanel(ctrlpanel.ControlPanel):
         for f, l in zip(treefiles, treelabels):
             self.__treeChoice.Append(l, clientData=f)
 
+        notesChoices = list(strings.choices[self, 'notes'].items())
+        for key, label in notesChoices:
+            self.__notesChoice.Append(label, clientData=key)
+
+        self.__treeChoice .SetSelection(0)
+        self.__notesChoice.SetSelection(0)
+        self.__fileList   .NotesColumn(notesChoices[0][0])
+
         self.__loadDir   .SetLabel(strings.labels[self, 'loadDir'])
         self.__customTree.SetLabel(strings.labels[self, 'customTree'])
         self.__save      .SetLabel(strings.labels[self, 'save'])
+        self.__notesLabel.SetLabel(strings.labels[self, 'notes'])
+
+        self.__mainSizer  = wx.BoxSizer(wx.VERTICAL)
+        self.__topSizer   = wx.BoxSizer(wx.HORIZONTAL)
+        self.__notesSizer = wx.BoxSizer(wx.HORIZONTAL)
+        self.__leftSizer  = wx.BoxSizer(wx.VERTICAL)
+        self.__rightSizer = wx.BoxSizer(wx.VERTICAL)
+
+        self.__notesSizer.Add(self.__notesLabel,  flag=wx.EXPAND)
+        self.__notesSizer.Add(self.__notesChoice, flag=wx.EXPAND, proportion=1)
+
+        self.__leftSizer.Add(self.__fileTypes,  flag=wx.EXPAND, proportion=1)
+        self.__leftSizer.Add(self.__varPanel,   flag=wx.EXPAND)
+        self.__leftSizer.Add(self.__notesSizer, flag=wx.EXPAND)
+
+        self.__rightSizer.Add(self.__dirName,  flag=wx.EXPAND)
+        self.__rightSizer.Add(self.__fileList, flag=wx.EXPAND, proportion=1)
 
-        self.__topSizer = wx.BoxSizer(wx.HORIZONTAL)
         self.__topSizer.Add(self.__treeChoice, flag=wx.EXPAND, proportion=1)
         self.__topSizer.Add(self.__loadDir,    flag=wx.EXPAND, proportion=1)
         self.__topSizer.Add(self.__customTree, flag=wx.EXPAND, proportion=1)
         self.__topSizer.Add(self.__save,       flag=wx.EXPAND, proportion=1)
 
-        self.__mainSizer = wx.BoxSizer(wx.VERTICAL)
         self.__mainSizer.Add(self.__topSizer,     flag=wx.EXPAND)
-        self.__mainSizer.Add(self.__dirName,      flag=wx.EXPAND)
         self.__mainSizer.Add(self.__mainSplitter, flag=wx.EXPAND, proportion=1)
 
-        self.SetSizer(self.__mainSizer)
+        self             .SetSizer(self.__mainSizer)
+        self.__leftPanel .SetSizer(self.__leftSizer)
+        self.__rightPanel.SetSizer(self.__rightSizer)
 
-        self.__loadDir   .Bind(wx.EVT_BUTTON, self._onLoadDir)
-        self.__customTree.Bind(wx.EVT_BUTTON, self._onCustomTree)
-        self.__treeChoice.Bind(wx.EVT_CHOICE, self._onTreeChoice)
-        self.__save      .Bind(wx.EVT_BUTTON, self._onSave)
+        self.__loadDir    .Bind(wx.EVT_BUTTON, self._onLoadDir)
+        self.__customTree .Bind(wx.EVT_BUTTON, self._onCustomTree)
+        self.__treeChoice .Bind(wx.EVT_CHOICE, self._onTreeChoice)
+        self.__save       .Bind(wx.EVT_BUTTON, self._onSave)
+        self.__notesChoice.Bind(wx.EVT_CHOICE, self._onNotesChoice)
 
 
     @property
@@ -275,6 +299,8 @@ class FileTreePanel(ctrlpanel.ControlPanel):
         dirname  = dlg.GetPath()
         treename = self._getTreeChoice()
 
+        fslsettings.write('loadSaveOverlayDir', dirname)
+
         self._loadTree(treename, dirname)
 
 
@@ -340,6 +366,15 @@ class FileTreePanel(ctrlpanel.ControlPanel):
                 f.write('\t'.join(row) + '\n')
 
 
+    def _onNotesChoice(self, ev):
+        """Called when the user changes the notes column position choice.
+        Calls :meth:`FileListPanel.NotesColumn` accordingly.
+        """
+        sel = self.__notesChoice.GetSelection()
+        sel = self.__notesChoice.GetClientData(sel)
+        self.__fileList.NotesColumn(sel)
+
+
 class FileTypePanel(elb.EditableListBox):
     """The ``FileTypePanel`` displays a list of available file types.
     It allows the user to choose which file types should be displayed.
@@ -532,21 +567,33 @@ class FileListPanel(wx.Panel):
     trigger a call to :meth:`.FileTreeManager.reorder`.
 
 
-    A text control is added at the end of each row, allowing the user to add
-    notes.
+    A *Notes* column contains text controls in each row, allowing the user to
+    add notes. The position of this column can be set to either left or right
+    of the fixed variable columns via the :meth:`NotesColumn` method.
     """
 
 
-    def __init__(self, parent, ftpanel):
+    def __init__(self, parent, ftpanel, notes='right'):
         """Create a ``FileListPanel``.
 
         :arg parent:  ``wx`` parent object
         :arg ftpanel: The :class:`.FileTreePanel`
+        :arg notes:   Location of the *Notes* column - one of:
+                        - ``'right'`` - right-most column (default)
+                        - ``'left'``  - left-most column, after varying
+                          columns
+
+        The *Notes* column location can be changed later via the
+        :meth:`NotesColumn` method.
         """
 
+        if notes not in ('left', 'right'):
+            raise ValueError('Invalid value for notes: {}'.format(notes))
+
         wx.Panel.__init__(self, parent)
 
         self.__ftpanel = ftpanel
+        self.__notes   = notes
         self.__mgr     = None
         self.__sizer   = wx.BoxSizer(wx.VERTICAL)
         self.__grid    = wgrid.WidgetGrid(
@@ -577,7 +624,6 @@ class FileListPanel(wx.Panel):
         fgroups    = mgr.filegroups
         grid       = self.__grid
         collabels  = self.__genColumnLabels(varcols, fixedcols)
-        collabels  = collabels + [strings.labels[self, 'notes']]
         nrows      = len(fgroups)
         ncols      = len(collabels)
 
@@ -595,6 +641,31 @@ class FileListPanel(wx.Panel):
         grid.Refresh()
 
 
+    def NotesColumn(self, notes):
+        """Set the position of the *Notes* column, either ``'left'`` or
+        ``'right'`` of the fixed variable columns.
+        """
+
+        if notes not in ('left', 'right'):
+            raise ValueError('Invalid value for notes: {}'.format(notes))
+
+        nrows, ncols = self.__grid.GetGridSize()
+        oldnotes     = self.__notes
+        self.__notes = notes
+
+        if nrows    == 0:     return
+        if oldnotes == notes: return
+
+        nvarcols = len(self.__mgr.varcols)
+        order    = list(range(ncols))
+
+        if notes == 'left': order.insert(nvarcols, order.pop(-1))
+        else:               order.append(order.pop(nvarcols))
+
+        self.__grid.ReorderColumns(order)
+        self.__grid.Refresh()
+
+
     def GridContents(self):
         """Returns the contents of the grid as a list of lists of strings. """
 
@@ -607,9 +678,9 @@ class FileListPanel(wx.Panel):
             widget = grid.GetWidget(row, col)
 
             # widget is either a StaticText
-            # or (last column) a TextCtrl
-            if col < ncols - 1: value = widget.GetLabel()
-            else:               value = widget.GetValue()
+            # or a TextCtrl (notes column)
+            if isinstance(widget, wx.TextCtrl): value = widget.GetValue()
+            else:                               value = widget.GetLabel()
 
             if value == PRESENTLBL:
                 value = 'x'
@@ -625,11 +696,12 @@ class FileListPanel(wx.Panel):
         are retrieved from the :class:`.FileTreeManager`.
         """
 
-        mgr     = self.__mgr
-        grid    = self.__grid
-        fgroups = mgr.filegroups
-        varcols = mgr.varcols
-        msg     = strings.messages[self, 'buildingList']
+        mgr      = self.__mgr
+        grid     = self.__grid
+        fgroups  = mgr.filegroups
+        varcols  = mgr.varcols
+        fixedoff = 1 if self.__notes == 'left' else 0
+        msg      = strings.messages[self, 'buildingList']
 
         fwoverlay.textOverlay(self.__grid, msg)
 
@@ -646,7 +718,8 @@ class FileListPanel(wx.Panel):
             # Fixed variable columns have a
             # bullet indicating whether or
             # not each file is present
-            for coli, filename in enumerate(fgroup.files, len(varcols)):
+            for coli, filename in enumerate(fgroup.files,
+                                            len(varcols) + fixedoff):
                 if filename is not None: grid.SetText(rowi, coli, PRESENTLBL)
                 else:                    grid.SetText(rowi, coli, '')
 
@@ -654,17 +727,30 @@ class FileListPanel(wx.Panel):
         self.Update()
 
 
+    def __notesIndex(self):
+        """Returns the column index of the notes column. Assumes that a
+        :class:`.FileTreeManager` has been passed to :meth:`.ResetGrid`.
+        """
+
+        nvarcols   = len(self.__mgr.varcols)
+        nfixedcols = len(self.__mgr.fixedcols)
+
+        if self.__notes == 'left': return nvarcols
+        else:                      return nvarcols + nfixedcols
+
+
     def __createNotes(self):
         """Called by :meth:`ResetGrid`. Creates a ``wx.TextCtrl`` for each
         row, and adds it to the end column.
         """
 
         grid         = self.__grid
+        notesIdx     = self.__notesIndex()
         nrows, ncols = grid.GetGridSize()
 
         for i in range(nrows):
             note = wx.TextCtrl(grid, i)
-            grid.SetWidget(i, ncols - 1, note)
+            grid.SetWidget(i, notesIdx, note)
             note.Bind(wx.EVT_CHAR_HOOK, self.__noteCharHook)
 
 
@@ -685,6 +771,7 @@ class FileListPanel(wx.Panel):
         else:                                                     offset = 1
 
         grid         = self.__grid
+        notesIdx     = self.__notesIndex()
         nrows, ncols = grid.GetGridSize()
         oldrow       = ev.GetEventObject().GetId()
         newrow       = oldrow + offset
@@ -693,7 +780,7 @@ class FileListPanel(wx.Panel):
         elif newrow >= nrows: newrow = nrows - 1
 
         if newrow != oldrow:
-            grid.GetWidget(newrow, ncols - 1).SetFocus()
+            grid.GetWidget(newrow, notesIdx).SetFocus()
             grid.SetSelection(newrow, -1)
 
 
@@ -756,7 +843,7 @@ class FileListPanel(wx.Panel):
 
     def __genColumnLabels(self, varcols, fixedcols):
         """Called by :meth:`ResetGrid`. Generates a label for each column in
-        the grid.
+        the grid, including the *Notes* column if it is visible.
 
         :arg varcols:   List of varying variable names
 
@@ -792,4 +879,11 @@ class FileListPanel(wx.Panel):
 
             collabels.append(lbl)
 
+        # notes column (if visible) is on the
+        # left or right of the fixed columns
+        if self.__notes == 'left':
+            collabels.insert(len(varcols), strings.labels[self, 'notes'])
+        else:
+            collabels.append(strings.labels[self, 'notes'])
+
         return collabels
