@@ -570,8 +570,8 @@ class GLContext(object):
         haveGui          = fslplatform.haveGui
 
         # On-screen contexts *must* be
-        # created on the wx.MainLoop
-        if (not offscreen) and (not haveGui):
+        # created via a wx event loop
+        if (not offscreen) and not (haveGui or createApp):
             raise ValueError('On-screen GL contexts must be '
                              'created on the wx.MainLoop')
 
@@ -660,6 +660,13 @@ class GLContext(object):
                 log.debug('Starting temporary wx.MainLoop')
                 self.__app.MainLoop()
 
+                # Once the GL context has been
+                # created, we no longer need
+                # references to the wx objects
+                self.__parent = None
+                self.__canvas = None
+                self.__app    = None
+
 
     def setTarget(self, target):
         """Set the given ``WXGLCanvasTarget`` or ``OffScreenCanvasTarget`` as
@@ -1065,8 +1072,10 @@ class WXGLCanvasTarget(object):
             # Just in case this canvas
             # was destroyed before it
             # had a chance to be drawn
-            # on
-            except wx.PyDeadObjectError:
+            # on - wxpython raises a
+            # RuntimeError on attempts
+            # to use deleted wx objects
+            except RuntimeError:
                 pass
 
         if not self.__glReady:
